window.Gleam.initSearch([{"doc":"gbase32_clockwork","title":"gbase32_clockwork","content":"# gbase32_clockwork\n\n## About\n\nI wanted to try implementing base32_clockwork in Gleam.  \nInspired by [shiguredo/base32_clockwork][1] and [this gist][2].\n\n[1]: https://github.com/shiguredo/base32_clockwork\n[2]: https://gist.github.com/szktty/228f85794e4187882a77734c89c384a8\n\n## Usage\n\n[![Package Version](https://img.shields.io/hexpm/v/gbase32_clockwork)](https://hex.pm/packages/gbase32_clockwork)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gbase32_clockwork/)\n\n```sh\ngleam add gbase32_clockwork\n```\n```gleam\nimport gbase32_clockwork/gbase32\nimport gleam/result\nimport gleam/string\nimport gleeunit/should\n\npub fn main() {\n  // create a reusable encoder\n  let encode = gbase32.new_encoder()\n  \n  // by default, lowercase is emitted\n  encode(&quot;foobar&quot;)\n  |&gt; should.equal(Ok(&quot;csqpyrk1e8&quot;))\n\n  // to emit as uppercase, simply uppercase the output string\n  encode(&quot;foobar&quot;)\n  |&gt; result.map(string.uppercase)\n  |&gt; should.equal(Ok(&quot;CSQPYRK1E8&quot;))\n\n  // create a reusable encoder\n  let decode = gbase32.new_encoder()\n\n  // a decoder will decode both upper and lowercase\n  decode(&quot;CSQPYRG&quot;)\n  |&gt; should.equal(Ok(&quot;foob&quot;))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gbase32_clockwork&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"gbase32_clockwork/gbase32","title":"new_decoder","content":"pub fn new_decoder() -&gt; fn(String) -&gt; Result(String, String)\n Create a new decoder that can be be reused to decode strings from base32 clockwork\n\n ## Examples\n\n \n let decode = new_decoder()\n decode(&quot;CSQPYRK1E8&quot;)\n // -&gt; Ok(&quot;foobar&quot;)\n \n\nSynonyms:\ngbase32_clockwork/gbase32.new_decoder\ngbase32_clockwork/gbase32 new_decoder","url":"gbase32_clockwork/gbase32.html#new_decoder"},{"doc":"gbase32_clockwork/gbase32","title":"new_encoder","content":"pub fn new_encoder() -&gt; fn(String) -&gt; Result(String, String)\n Create a new encoder that can be be reused to encode strings in base32 clockwork\n\n ## Examples\n\n \n let encode = new_encoder()\n encode(&quot;foobar&quot;)\n // -&gt; Ok(&quot;csqpyrk1e8&quot;)\n \n\nSynonyms:\ngbase32_clockwork/gbase32.new_encoder\ngbase32_clockwork/gbase32 new_encoder","url":"gbase32_clockwork/gbase32.html#new_encoder"},{"doc":"gbase32_clockwork/gbase32","title":"gbase32_clockwork/gbase32","content":"","url":"gbase32_clockwork/gbase32.html"}]);